@@ -14,7 +14,7 @@ from eurosatory.crawler import test_eurosatory
 from dcinside.crawler import test_dcinside_crawler
 from exposeguridadmexico.crawler import test_expo_guarid
 from coupang.reviews import crawl_coupang_review
-from afreeca import cast
+from kosca.ks import crawl_kosca, run_crawler, compose_excel
 
 def main():
     argparser = argparse.ArgumentParser(
@@ -26,6 +26,8 @@ def main():
     argparser.add_argument('-ip', '--ip', default='52.79.116.98')
     argparser.add_argument('-start_date', '--start_date', default='')
     argparser.add_argument('-end_date', '--end_date', default='')
+    argparser.add_argument('-start_page', '--page_start', type=int, default=1)
+    argparser.add_argument('-end_page', '--page_end', type=int,  default=1)
     argparser.add_argument('-search', '--search', nargs='?', default='')
     argparser.add_argument('-page_range', '--page_range', nargs='?')
 
@@ -77,8 +79,13 @@ def main():
     if args.appname == 'coupang':
         crawl_coupang_review(page_range=(2, 2))
 
-    if args.appname == 'afreeca':
-        cast.test()
+    if args.appname == 'kosca':
+        # run_crawler()
+        crawl_kosca(page_start=args.page_start, page_end=args.page_end)
 
-if __name__ == '__main__':
+    if args.appname == 'kosca-compose-excel':
+        compose_excel()
+    
+
+if __name__ == '__main__':  
     main()
\ No newline at end of file
