@@ -38,7 +38,7 @@ class NaverKinCrawler(BaseCrawler):
         # {'https':'103.37.141.68:80'},
         # None,
         # {'https':'140.227.61.156:23456'},
-        {'https':'121.254.195.12:8080'},
+        # {'https':'121.254.195.12:8080'},
     ]
 
     urlorders = [
@@ -197,9 +197,7 @@ class NaverKinCrawler(BaseCrawler):
         return 10
         
 
-
 def event_listener(crawler, event, visit_count, response):
-    print(crawler, event, visit_count)
     if response:
         print(response.url)
     return True
